require('./file-test')
require('./locator')
require('./namespace')
require('./node')
require('./parse-element')
require('./simple')
require('./test-define')
require('./test-doc-witespace')
require('./unclosedcomment')